# PG::Instrumentation

This gem provides OpenTracing instrumentation for [pg](https://github.com/ged/ruby-pg).

## Supported versions

- MRI Ruby 2.0 and newer
- Pg 0.18.0 and newer

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'pg-instrumentation'
```

And then execute:

    $ bundle

Or install it yourself as:

    $ gem install pg-instrumentation

## Usage

Before creating a new pg client, add this code:

```ruby
require 'pg/instrumentation'

PG::Instrumentation.instrument(tracer: tracer)
```

`instrument` takes an optional parameter, `:tracer`, which explicitly sets the tracer to use. 
If not provided, the instrumentation will default to the
OpenTracing global tracer (`OpenTracing.global_tracer`).

##Tags

Each span generated by the instrumentation will have the following tags:

- `component`: `pg`
- `span.kind`: `client`
- `db.type`: The database driver type. For example, `pg`
- `db.instance`: The name of the pg instance
- `db.user`: The user of the pg instance
- `peer.hostname`: The hostname of the pg server
- `peer.port`: The port of the pg server
- `peer.address`: The address of the pg server set as `pg://host:port`, for example `pg://localhost:5432`

## Development

After checking out the repo, run `bin/setup` to install dependencies. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).


### Unit tests

Run the RSpec tests with

```bash
bundle exec rspec
```


## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/signalfx/ruby-pg-instrumentation.

## License

The gem is available as open source under the terms of the [Apache 2.0 License](https://opensource.org/licenses/Apache-2.0).
